# Schedwi
# Copyright (C) 2011, 2012 Herve Quatremain
#
# This file is part of Schedwi.
#
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from sqlalchemy.schema import Column, ForeignKey
from sqlalchemy.types import Integer

from base import Base


class link(Base):
    __tablename__ = 'link'

    job_id_source = Column(Integer, ForeignKey('job_main.id'),
                           primary_key=True)
    job_id_destination = Column(Integer, ForeignKey('job_main.id'),
                                primary_key=True)
    required_status = Column(Integer)

    def __init__(self, job_id_destination, required_status):
        self.job_id_destination = job_id_destination
        self.required_status = required_status

    def copy(self):
        return link(self.job_id_destination, self.required_status)
